Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/hatch_ci/__init__.py | 2 | 0 | 0 | 0 | 0 | 100%
src/hatch_ci/__main__.py | 41 | 41 | 2 | 12 | 0 | 0%
src/hatch_ci/common.py | 1 | 1 | 0 | 0 | 0 | 0%
src/hatch_ci/hooks.py | 5 | 5 | 0 | 0 | 0 | 0%
src/hatch_ci/scm.py | 158 | 29 | 0 | 50 | 7 | 80%
src/hatch_ci/tools.py | 156 | 9 | 0 | 70 | 8 | 91%
src/hatch_ci/version_hook.py | 17 | 17 | 0 | 2 | 0 | 0%
Total | 380 | 102 | 2 | 134 | 15 | 73%

No items found using the specified filter.